# Описание
Замечательная библиотека разных структур для реализации на языке python

[Все, что используется в модуле AISD](https://github.com/Ackrome/matplobblib/tree/master/matplobblib/AISD)<br>
[Все, что используется в модуле TVIMS](https://github.com/Ackrome/matplobblib/tree/master/matplobblib/TVIMS)
